==> zzyj-laborservice-api-3.0.0-20241216.062822-64-sources.jar: com/ejianc/business/itax/vo/SalaryDetailVO.java <==
package com.ejianc.business.itax.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工人工资上传明细
 * 
 * @author generator
 * 
 */
public class SalaryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long operatorId; // 经办人ID
    private String operatorName; // 劳务队长人姓名
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private Long projectId; // 项目id
    private String projectCode; // 项目code
    private String projectName; // 项目
    private String idNum; // 身份证号
    private String name; // 姓名
    private String phone; // 联系电话
    private BigDecimal money; // 本次发放金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date effectiveStartTime; // 有效开始日期
    private Long pid; // 父id
    private String errorMsg;
    private Integer monthNum; // 计算个税入职月份
    private String isRegist; // 是否在系统登记
    private String lastMonthState; // 上月申报状态
    private Integer thisMonthNum; // 本月代发次数
    private BigDecimal thisYearIncome; // 截至本单已申报本年度累计收入
    private BigDecimal thisMonthDlffje; // 本月累计办理代发金额
    private BigDecimal thisMonthIncomeItax; // 本月应纳税所得额
    private BigDecimal expenseReduction; // 累计减除费用
    private BigDecimal thisYearItax; // 截至本月已申报个税
    private BigDecimal thisMonthPrepayItax; // 本月预缴个税
    private BigDecimal specialDeduction; // 专项附加扣除
    private BigDecimal lastMonthWsbItax; // 上月未申报个税
    private BigDecimal lastMonthWsbIncome; // 上月未申报收入金额
    private BigDecimal thisMonthItax; // 计算个税
    private BigDecimal thisMonthItaxYj; // 已交个税
    private String salaryPayState; // 工资发放状态
    private Integer userState; // 人员状态(1已在系统中登记2未在系统中登记)
    private String itaxState; // 个税收取状态


    public String getItaxState() {
        return itaxState;
    }

    public void setItaxState(String itaxState) {
        this.itaxState = itaxState;
    }

    public Integer getUserState() {
        return userState;
    }

    public void setUserState(Integer userState) {
        this.userState = userState;
    }

    public String getSalaryPayState() {
        return salaryPayState;
    }

    public void setSalaryPayState(String salaryPayState) {
        this.salaryPayState = salaryPayState;
    }

    public Integer getMonthNum() {
        return monthNum;
    }

    public void setMonthNum(Integer monthNum) {
        this.monthNum = monthNum;
    }

    public String getIsRegist() {
        return isRegist;
    }

    public void setIsRegist(String isRegist) {
        this.isRegist = isRegist;
    }

    public String getLastMonthState() {
        return lastMonthState;
    }

    public void setLastMonthState(String lastMonthState) {
        this.lastMonthState = lastMonthState;
    }

    public Integer getThisMonthNum() {
        return thisMonthNum;
    }

    public void setThisMonthNum(Integer thisMonthNum) {
        this.thisMonthNum = thisMonthNum;
    }

    public BigDecimal getThisYearIncome() {
        return thisYearIncome;
    }

    public void setThisYearIncome(BigDecimal thisYearIncome) {
        this.thisYearIncome = thisYearIncome;
    }

    public BigDecimal getThisMonthDlffje() {
        return thisMonthDlffje;
    }

    public void setThisMonthDlffje(BigDecimal thisMonthDlffje) {
        this.thisMonthDlffje = thisMonthDlffje;
    }

    public BigDecimal getThisMonthIncomeItax() {
        return thisMonthIncomeItax;
    }

    public void setThisMonthIncomeItax(BigDecimal thisMonthIncomeItax) {
        this.thisMonthIncomeItax = thisMonthIncomeItax;
    }

    public BigDecimal getExpenseReduction() {
        return expenseReduction;
    }

    public void setExpenseReduction(BigDecimal expenseReduction) {
        this.expenseReduction = expenseReduction;
    }

    public BigDecimal getThisYearItax() {
        return thisYearItax;
    }

    public void setThisYearItax(BigDecimal thisYearItax) {
        this.thisYearItax = thisYearItax;
    }

    public BigDecimal getThisMonthPrepayItax() {
        return thisMonthPrepayItax;
    }

    public void setThisMonthPrepayItax(BigDecimal thisMonthPrepayItax) {
        this.thisMonthPrepayItax = thisMonthPrepayItax;
    }

    public BigDecimal getSpecialDeduction() {
        return specialDeduction;
    }

    public void setSpecialDeduction(BigDecimal specialDeduction) {
        this.specialDeduction = specialDeduction;
    }

    public BigDecimal getLastMonthWsbItax() {
        return lastMonthWsbItax;
    }

    public void setLastMonthWsbItax(BigDecimal lastMonthWsbItax) {
        this.lastMonthWsbItax = lastMonthWsbItax;
    }

    public BigDecimal getLastMonthWsbIncome() {
        return lastMonthWsbIncome;
    }

    public void setLastMonthWsbIncome(BigDecimal lastMonthWsbIncome) {
        this.lastMonthWsbIncome = lastMonthWsbIncome;
    }

    public BigDecimal getThisMonthItax() {
        return thisMonthItax;
    }

    public void setThisMonthItax(BigDecimal thisMonthItax) {
        this.thisMonthItax = thisMonthItax;
    }

    public BigDecimal getThisMonthItaxYj() {
        return thisMonthItaxYj;
    }

    public void setThisMonthItaxYj(BigDecimal thisMonthItaxYj) {
        this.thisMonthItaxYj = thisMonthItaxYj;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getIdNum() {
        return idNum;
    }

    public void setIdNum(String idNum) {
        this.idNum = idNum;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public Date getEffectiveStartTime() {
        return effectiveStartTime;
    }

    public void setEffectiveStartTime(Date effectiveStartTime) {
        this.effectiveStartTime = effectiveStartTime;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> zzyj-laborservice-api-3.0.0-20250109.084207-71-sources.jar: com/ejianc/business/itax/vo/SalaryDetailVO.java <==
package com.ejianc.business.itax.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工人工资上传明细
 * 
 * @author generator
 * 
 */
public class SalaryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long operatorId; // 经办人ID
    private String operatorName; // 劳务队长人姓名
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private Long projectId; // 项目id
    private String projectCode; // 项目code
    private String projectName; // 项目
    private String idNum; // 身份证号
    private String name; // 姓名
    private String phone; // 联系电话
    private BigDecimal money; // 本次发放金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date effectiveStartTime; // 有效开始日期
    private Long pid; // 父id
    private String errorMsg;
    private Integer monthNum; // 计算个税入职月份
    private String isRegist; // 是否在系统登记
    private String lastMonthState; // 上月申报状态
    private Integer thisMonthNum; // 本月代发次数
    private BigDecimal thisYearIncome; // 截至本单已申报本年度累计收入
    private BigDecimal thisMonthDlffje; // 本月累计办理代发金额
    private BigDecimal thisMonthIncomeItax; // 本月应纳税所得额
    private BigDecimal expenseReduction; // 累计减除费用
    private BigDecimal thisYearItax; // 截至本月已申报个税
    private BigDecimal thisMonthPrepayItax; // 本月预缴个税
    private BigDecimal specialDeduction; // 专项附加扣除
    private BigDecimal lastMonthWsbItax; // 上月未申报个税
    private BigDecimal lastMonthWsbIncome; // 上月未申报收入金额
    private BigDecimal thisMonthItax; // 计算个税
    private BigDecimal thisMonthItaxYj; // 已交个税
    private String salaryPayState; // 工资发放状态
    private Integer userState; // 人员状态(1已在系统中登记2未在系统中登记)
    private String itaxState; // 个税收取状态
    private Long expendContractId; // 支出合同id
    private String expendContractName; // 支出合同名称
    private String expendContractCode; // 支出合同编号
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date billTime; // 上传日期


    public Long getExpendContractId() {
        return expendContractId;
    }

    public void setExpendContractId(Long expendContractId) {
        this.expendContractId = expendContractId;
    }

    public String getExpendContractName() {
        return expendContractName;
    }

    public void setExpendContractName(String expendContractName) {
        this.expendContractName = expendContractName;
    }

    public String getExpendContractCode() {
        return expendContractCode;
    }

    public void setExpendContractCode(String expendContractCode) {
        this.expendContractCode = expendContractCode;
    }

    public Date getBillTime() {
        return billTime;
    }

    public void setBillTime(Date billTime) {
        this.billTime = billTime;
    }

    public String getItaxState() {
        return itaxState;
    }

    public void setItaxState(String itaxState) {
        this.itaxState = itaxState;
    }

    public Integer getUserState() {
        return userState;
    }

    public void setUserState(Integer userState) {
        this.userState = userState;
    }

    public String getSalaryPayState() {
        return salaryPayState;
    }

    public void setSalaryPayState(String salaryPayState) {
        this.salaryPayState = salaryPayState;
    }

    public Integer getMonthNum() {
        return monthNum;
    }

    public void setMonthNum(Integer monthNum) {
        this.monthNum = monthNum;
    }

    public String getIsRegist() {
        return isRegist;
    }

    public void setIsRegist(String isRegist) {
        this.isRegist = isRegist;
    }

    public String getLastMonthState() {
        return lastMonthState;
    }

    public void setLastMonthState(String lastMonthState) {
        this.lastMonthState = lastMonthState;
    }

    public Integer getThisMonthNum() {
        return thisMonthNum;
    }

    public void setThisMonthNum(Integer thisMonthNum) {
        this.thisMonthNum = thisMonthNum;
    }

    public BigDecimal getThisYearIncome() {
        return thisYearIncome;
    }

    public void setThisYearIncome(BigDecimal thisYearIncome) {
        this.thisYearIncome = thisYearIncome;
    }

    public BigDecimal getThisMonthDlffje() {
        return thisMonthDlffje;
    }

    public void setThisMonthDlffje(BigDecimal thisMonthDlffje) {
        this.thisMonthDlffje = thisMonthDlffje;
    }

    public BigDecimal getThisMonthIncomeItax() {
        return thisMonthIncomeItax;
    }

    public void setThisMonthIncomeItax(BigDecimal thisMonthIncomeItax) {
        this.thisMonthIncomeItax = thisMonthIncomeItax;
    }

    public BigDecimal getExpenseReduction() {
        return expenseReduction;
    }

    public void setExpenseReduction(BigDecimal expenseReduction) {
        this.expenseReduction = expenseReduction;
    }

    public BigDecimal getThisYearItax() {
        return thisYearItax;
    }

    public void setThisYearItax(BigDecimal thisYearItax) {
        this.thisYearItax = thisYearItax;
    }

    public BigDecimal getThisMonthPrepayItax() {
        return thisMonthPrepayItax;
    }

    public void setThisMonthPrepayItax(BigDecimal thisMonthPrepayItax) {
        this.thisMonthPrepayItax = thisMonthPrepayItax;
    }

    public BigDecimal getSpecialDeduction() {
        return specialDeduction;
    }

    public void setSpecialDeduction(BigDecimal specialDeduction) {
        this.specialDeduction = specialDeduction;
    }

    public BigDecimal getLastMonthWsbItax() {
        return lastMonthWsbItax;
    }

    public void setLastMonthWsbItax(BigDecimal lastMonthWsbItax) {
        this.lastMonthWsbItax = lastMonthWsbItax;
    }

    public BigDecimal getLastMonthWsbIncome() {
        return lastMonthWsbIncome;
    }

    public void setLastMonthWsbIncome(BigDecimal lastMonthWsbIncome) {
        this.lastMonthWsbIncome = lastMonthWsbIncome;
    }

    public BigDecimal getThisMonthItax() {
        return thisMonthItax;
    }

    public void setThisMonthItax(BigDecimal thisMonthItax) {
        this.thisMonthItax = thisMonthItax;
    }

    public BigDecimal getThisMonthItaxYj() {
        return thisMonthItaxYj;
    }

    public void setThisMonthItaxYj(BigDecimal thisMonthItaxYj) {
        this.thisMonthItaxYj = thisMonthItaxYj;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getIdNum() {
        return idNum;
    }

    public void setIdNum(String idNum) {
        this.idNum = idNum;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public Date getEffectiveStartTime() {
        return effectiveStartTime;
    }

    public void setEffectiveStartTime(Date effectiveStartTime) {
        this.effectiveStartTime = effectiveStartTime;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
